# Credits

* [Jürno Ader](https://github.com/Jyrno42) <jyrno@thorgate.eu>
* [Rivo Laks](https://github.com/rivol)
* [Hanno Särg](https://github.com/wanaryytel)
* [Jörgen Ader](https://github.com/metsavaht)
* [Kaspar Kask](https://github.com/kaspar92)
* [Simon Schmidt](https://github.com/simonschmidt)
* [Yuriy Shatrov](https://github.com/ykshatroff)
